@@ -680,7 +680,11 @@ def MWW(X,y, verbose = False, show = False, max_plot_num = 5):
 
         Xcis = np.array(Xcis)         
         
-        U,p = scipy.stats.mannwhitneyu(Xcis[0], Xcis[1])    
+        if np.allclose(Xcis[0], Xcis[1]): # ValueError: All numbers are identical in mannwhitneyu
+            U = len(Xcis[0]) * len(Xcis[1]) / 2 # return the theoretical U max: n1*n2/2
+            p = 1 # theoretical max. SPSS will return p = 1.0 for identical samples.
+        else:
+            U,p = scipy.stats.mannwhitneyu(Xcis[0], Xcis[1]) 
         
         ps.append(p)
         Us.append(U)
